==> core-react-0.8.0.tgz: package/es/Switch/index.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';


var Switch = /*#__PURE__*/function (_React$Component) {
  _inherits(Switch, _React$Component);

  function Switch(props) {
    var _this;

    _classCallCheck(this, Switch);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Switch).call(this));

    _defineProperty(_assertThisInitialized(_this), "handleChange", function (e) {
      e.stopPropagation();

      _this.setState({
        on: e.target.checked
      });

      _this.props.onChange && _this.props.onChange(e.target.checked);
    });

    _this.state = {
      on: props.on || props.defaultOn || false
    };
    return _this;
  }

  _createClass(Switch, [{
    key: "render",
    value: function render() {
      var _this$props = this.props,
          className = _this$props.className,
          defaultOn = _this$props.defaultOn,
          onChange = _this$props.onChange,
          labelOn = _this$props.labelOn,
          labelOff = _this$props.labelOff,
          other = _objectWithoutProperties(_this$props, ["className", "defaultOn", "onChange", "labelOn", "labelOff"]);

      var on = this.state.on;
      delete other.on;
      return React.createElement("label", _extends({
        className: cx("".concat("waui", "-switch"), className)
      }, other), React.createElement("input", {
        type: "checkbox",
        checked: on,
        onChange: this.handleChange
      }), React.createElement("span", {
        className: "".concat("waui", "-switch__text")
      }, on ? labelOn : labelOff));
    }
  }], [{
    key: "getDerivedStateFromProps",
    value: function getDerivedStateFromProps(nextProps, prevState) {
      if ('on' in nextProps) {
        return {
          on: nextProps.on
        };
      }

      return prevState;
    }
  }]);

  return Switch;
}(React.Component);

Switch.propTypes = {
  className: PropTypes.string,

  /** Whether to be on */
  on: PropTypes.bool,

  /** Whether to be on by default (uncontrolled) */
  defaultOn: PropTypes.bool,

  /** The callback after switching, param: (whether to be on) */
  onChange: PropTypes.func,

  /** The text of Switch which is on */
  labelOn: PropTypes.oneOfType([PropTypes.string, PropTypes.element]),

  /** The text of Switch which is off */
  labelOff: PropTypes.oneOfType([PropTypes.string, PropTypes.element]),
  customProp: function customProp(_ref) {
    var on = _ref.on,
        onChange = _ref.onChange;

    if (on && !onChange) {
      return new Error('You provided a `on` prop without an `onChange` handler');
    }
  }
};
export default Switch;

==> core-react-0.8.2.tgz: package/es/Switch/index.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';


var Switch = /*#__PURE__*/function (_React$Component) {
  _inherits(Switch, _React$Component);

  function Switch(props) {
    var _this;

    _classCallCheck(this, Switch);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Switch).call(this));

    _defineProperty(_assertThisInitialized(_this), "handleChange", function (e) {
      e.stopPropagation();

      _this.setState({
        on: e.target.checked
      });

      _this.props.onChange && _this.props.onChange(e.target.checked);
    });

    _this.state = {
      on: props.on || props.defaultOn || false
    };
    return _this;
  }

  _createClass(Switch, [{
    key: "render",
    value: function render() {
      var _this$props = this.props,
          className = _this$props.className,
          defaultOn = _this$props.defaultOn,
          onChange = _this$props.onChange,
          labelOn = _this$props.labelOn,
          labelOff = _this$props.labelOff,
          other = _objectWithoutProperties(_this$props, ["className", "defaultOn", "onChange", "labelOn", "labelOff"]);

      var on = this.state.on;
      delete other.on;
      return (/*#__PURE__*/React.createElement("label", _extends({
          className: cx("".concat("waui", "-switch"), className)
        }, other), /*#__PURE__*/React.createElement("input", {
          type: "checkbox",
          checked: on,
          onChange: this.handleChange
        }), /*#__PURE__*/React.createElement("span", {
          className: "".concat("waui", "-switch__text")
        }, on ? labelOn : labelOff))
      );
    }
  }], [{
    key: "getDerivedStateFromProps",
    value: function getDerivedStateFromProps(nextProps, prevState) {
      if ('on' in nextProps) {
        return {
          on: nextProps.on
        };
      }

      return prevState;
    }
  }]);

  return Switch;
}(React.Component);

Switch.propTypes = {
  className: PropTypes.string,

  /** Whether to be on */
  on: PropTypes.bool,

  /** Whether to be on by default (uncontrolled) */
  defaultOn: PropTypes.bool,

  /** The callback after switching, param: (whether to be on) */
  onChange: PropTypes.func,

  /** The text of Switch which is on */
  labelOn: PropTypes.oneOfType([PropTypes.string, PropTypes.element]),

  /** The text of Switch which is off */
  labelOff: PropTypes.oneOfType([PropTypes.string, PropTypes.element]),
  customProp: function customProp(_ref) {
    var on = _ref.on,
        onChange = _ref.onChange;

    if (on && !onChange) {
      return new Error('You provided a `on` prop without an `onChange` handler');
    }
  }
};
export default Switch;
